==> estateplat-common-1.2.4-20210317.030413-668-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjCbjyqJtcy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;
/**
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version V1.0, 2021/3/16
 * @description 土地承包经营权家庭成员
 */
@Table(name = "DJSJ_CBJYQ_JTCY")
public class DjsjCbjyqJtcy {
    @Id
    private String nyd_jtcy_index;
    private String jtcymc;
    private String sfzjzl;
    private String zjh;
    private String xb;
    private String lxdh;
    private Integer xh;
    private String yhzgx;
    private Date gxsj;
    private String hkszd;

    public String getJtcymc() {
        return jtcymc;
    }

    public void setJtcymc(String jtcymc) {
        this.jtcymc = jtcymc;
    }

    public String getSfzjzl() {
        return sfzjzl;
    }

    public void setSfzjzl(String sfzjzl) {
        this.sfzjzl = sfzjzl;
    }

    public String getZjh() {
        return zjh;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getYhzgx() {
        return yhzgx;
    }

    public void setYhzgx(String yhzgx) {
        this.yhzgx = yhzgx;
    }

    public Date getGxsj() {
        return gxsj;
    }

    public void setGxsj(Date gxsj) {
        this.gxsj = gxsj;
    }

    public String getHkszd() {
        return hkszd;
    }

    public void setHkszd(String hkszd) {
        this.hkszd = hkszd;
    }

    public String getNyd_jtcy_index() {
        return nyd_jtcy_index;
    }

    public void setNyd_jtcy_index(String nyd_jtcy_index) {
        this.nyd_jtcy_index = nyd_jtcy_index;
    }
}

==> estateplat-common-1.2.4-20230714.011633-1190-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjCbjyqJtcy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;
/**
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version V1.0, 2021/3/16
 * @description 土地承包经营权家庭成员
 */
@Table(name = "DJSJ_CBJYQ_JTCY")
public class DjsjCbjyqJtcy {
    @Id
    private String nyd_jtcy_index;
    private String jtcymc;
    private String sfzjzl;
    private String zjh;
    private String xb;
    private String lxdh;
    private Integer xh;
    private String yhzgx;
    private Date gxsj;
    private String hkszd;
    private String djh;
    private String bdcdyh;

    public String getJtcymc() {
        return jtcymc;
    }

    public void setJtcymc(String jtcymc) {
        this.jtcymc = jtcymc;
    }

    public String getSfzjzl() {
        return sfzjzl;
    }

    public void setSfzjzl(String sfzjzl) {
        this.sfzjzl = sfzjzl;
    }

    public String getZjh() {
        return zjh;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getYhzgx() {
        return yhzgx;
    }

    public void setYhzgx(String yhzgx) {
        this.yhzgx = yhzgx;
    }

    public Date getGxsj() {
        return gxsj;
    }

    public void setGxsj(Date gxsj) {
        this.gxsj = gxsj;
    }

    public String getHkszd() {
        return hkszd;
    }

    public void setHkszd(String hkszd) {
        this.hkszd = hkszd;
    }

    public String getNyd_jtcy_index() {
        return nyd_jtcy_index;
    }

    public void setNyd_jtcy_index(String nyd_jtcy_index) {
        this.nyd_jtcy_index = nyd_jtcy_index;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }
}
